@@ -106,13 +106,13 @@
 
 #define HAVE_COPC
 
-/* #undef HAVE_PDAL_QGIS */
-#define PDAL_VERSION ""
-#define PDAL_VERSION_MAJOR_INT 
-#define PDAL_VERSION_MINOR_INT 
-#define PDAL_VERSION_MAJOR ""
-#define PDAL_VERSION_MINOR ""
-#define PDAL_VERSION_MICRO ""
+#define HAVE_PDAL_QGIS
+#define PDAL_VERSION "2.7.1"
+#define PDAL_VERSION_MAJOR_INT 2
+#define PDAL_VERSION_MINOR_INT 7
+#define PDAL_VERSION_MAJOR "2"
+#define PDAL_VERSION_MINOR "7"
+#define PDAL_VERSION_MICRO "1"
 
 #define HAVE_DRACO
 
